"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("chromedriver");
const lib_1 = require("../../lib");
describe('Selene', () => {
    it('rocks on testing todomvc.com', async () => {
        await lib_1.browser.open('https://todomvc.com/examples/emberjs/');
        await lib_1.browser.element('#new-todo').type('10').then(lib_1.command.pressEnter);
        await lib_1.browser.element('#new-todo').type('20').then(lib_1.command.pressEnter);
        await lib_1.browser.element('#new-todo').type('30').then(lib_1.command.pressEnter);
        await lib_1.browser.all('#todo-list>li').should(lib_1.have.size(3));
        await lib_1.browser.all('#todo-list>li').first.should(lib_1.have.exactText('10'));
        await lib_1.browser.all('#todo-list>li').first.should(lib_1.have.exactText(10));
        await lib_1.browser.all('#todo-list>li').first.should(lib_1.have.text('1'));
        await lib_1.browser.all('#todo-list>li').first.should(lib_1.have.text(1));
        await lib_1.browser.all('#todo-list>li').should(lib_1.have.exactTexts('10', '20', '30'));
        await lib_1.browser.all('#todo-list>li').should(lib_1.have.exactTexts(10, 20, 30));
        await lib_1.browser.all('#todo-list>li').should(lib_1.have.exactTexts('10', 20, '30'));
        await lib_1.browser.all('#todo-list>li').should(lib_1.have.texts('1', '2', '3'));
        await lib_1.browser.all('#todo-list>li').should(lib_1.have.texts('1', 2, '3'));
        await lib_1.browser.all('#todo-list>li').even.should(lib_1.have.texts('2'));
        await lib_1.browser.all('#todo-list>li').odd.should(lib_1.have.texts('1', '3'));
        try {
            await lib_1.browser.all('#todo-list>li').odd.with({ timeout: 250 }).should(lib_1.have.texts('1', '4'));
            throw new Error('should fail');
        }
        catch (error) {
            expect(error.message).toContain(`
\tTimed out after 250ms, while waiting for:
\tbrowser.all(By(css selector, #todo-list>li))[::2].has texts 1,4
Reason:
\tactual texts: 10,30`.trim());
        }
        await lib_1.browser.all('#todo-list>li').sliced(0, undefined, -1).should(lib_1.have.texts(3, 2, 1));
    });
    it('rocks on testing the-internet.herokuapp.com/tables', async () => {
        await lib_1.browser.open('https://the-internet.herokuapp.com/tables');
        const table = lib_1.browser.element('#table1 tbody');
        /**
         * Actual Table Data
         Last Name 	First Name 	Email 	                Due 	    Web Site 	                Action
         Smith 	    John 	    jsmith@gmail.com 	    $50.00 	    http://www.jsmith.com 	    edit delete
         Bach 	    Frank 	    fbach@yahoo.com 	    $51.00 	    http://www.frank.com 	    edit delete
         Doe 	    Jason 	    jdoe@hotmail.com 	    $100.00 	http://www.jdoe.com 	    edit delete
         Conway 	Tim 	    tconway@earthlink.net 	$50.00 	    http://www.timconway.com 	edit delete
         */
        await table.all('tr').should(lib_1.have.size(4));
        await table.all('tr').first.all('td').sliced(0, -3).should(lib_1.have.texts('Smith', 'John', 'jsmith@gmail.com'));
        await table.all('tr').allFirst('td').should(lib_1.have.texts('Smith', 'Bach', 'Doe', 'Conway'));
        await table.all('tr').all('td').should(lib_1.have.texts('Smith', 'John', 'jsmith@gmail.com', '$50.00', 'http://www.jsmith.com', 'edit delete', 'Bach', 'Frank', 'fbach@yahoo.com', '$51.00', 'http://www.frank.com', 'edit delete', 'Doe', 'Jason', 'jdoe@hotmail.com', '$100.00', 'http://www.jdoe.com', 'edit delete', 'Conway', 'Tim', 'tconway@earthlink.net', '$50.00', 'http://www.timconway.com', 'edit delete'));
        await table.all('tr').odd.collected(its => its.all('td').sliced(0, -3)).should(lib_1.have.texts('Smith', 'John', 'jsmith@gmail.com', 'Doe', 'Jason', 'jdoe@hotmail.com'));
        await table.all('tr').even.collected(its => its.all('td').sliced(0, -3)).should(lib_1.have.texts('Bach', 'Frank', 'fbach@yahoo.com', 'Conway', 'Tim', 'tconway@earthlink.net'));
    });
    afterEach(async () => {
        await lib_1.browser.quit();
    });
});
//# sourceMappingURL=acceptance.test.js.map